﻿using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Encodings.PermutationEncoding;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.PTSP {
  public class TwoPointFiveMove : Item {
    
    [StorableConstructor]
    public TwoPointFiveMove() : this(-1, -1,null, true) { }
    protected TwoPointFiveMove(bool deserializing) : base(deserializing) { }
    protected TwoPointFiveMove(TwoPointFiveMove original, Cloner cloner)
      : base(original, cloner) {
      this.Index1 = original.Index1;
      this.Index2 = original.Index2;
      this.IsInvert = original.IsInvert;
      if (original.Permutation != null)
        this.Permutation = cloner.Clone(original.Permutation);
    }
    public TwoPointFiveMove(int index1, int index2, Permutation permutation, bool isinvert)
      : base() {
      Index1 = index1;
      Index2 = index2;
      IsInvert = isinvert;
      Permutation = permutation;
    }

    public TwoPointFiveMove(int index1, int index2, bool isinvert)
      : base() {
      Index1 = index1;
      Index2 = index2;
      IsInvert = isinvert;
      Permutation = null;
    }

    [Storable]
    public int Index1 { get; protected set; }
    [Storable]
    public int Index2 { get; protected set; }
    [Storable]
    public Permutation Permutation { get; protected set; }
    [Storable]
    public bool IsInvert { get; protected set; }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new TwoPointFiveMove(this, cloner);
    }
  }
}
